Pygments Tomorrow Night Bright
==============================

This is a pygments style based on the Tomorrow color scheme.


Installation
------------


From pypi:
::
    $ pip install pygments-style-tomorrownightbright


From Source:
::
    $ git clone https://github.com/gbraad/pygments-style-tomorrownightbright
    $ cd pygments-style-tomorrownightbright
    $ python setup.py install


Authors
-------

+-----------------------------------------+
| |"Gerard Braad"|                        |
+=========================================+
| `@gbraad <https://twitter.com/gbraad>`_ |
+-----------------------------------------+

.. |"Gerard Braad"| image:: http://gravatar.com/avatar/e466994eea3c2a1672564e45aca844d0.png?s=60
   :target: http://gbraad.nl
